"""Modal screen widgets."""

from claudechic.widgets.modals.profile import ProfileModal
from claudechic.widgets.modals.process_modal import ProcessModal
from claudechic.widgets.modals.process_detail import ProcessDetailModal

__all__ = [
    "ProfileModal",
    "ProcessModal",
    "ProcessDetailModal",
]
